@@ -1,10 +1,10 @@
 r"""
 This module exposes the :func:`ubelt.cmd` command, which provides a simple
-means for interacting with the commandline.  This uses
+means for interacting with the command line.  This uses
 :class:`subprocess.Popen` under the hood, but improves upon existing
 :mod:`subprocess` functionality by:
 
-(1) Adding the option to "tee" the output, i.e. simultaniously capture and
+(1) Adding the option to "tee" the output, i.e. simultaneously capture and
 write to stdout and stderr.
 
 (2) Always specify the command as a string. The :mod:`subprocess` module
@@ -12,7 +12,7 @@ expects the command as either a  ``List[str]`` if ``shell=False`` and ``str``
 if ``shell=True``. If necessary, :func:`ubelt.util_cmd.cmd` will automatically
 convert from one format to the other, so passing in either case will work.
 
-(3) Specificy if the process blocks or not by setting ``detach``. Note: when
+(3) Specify if the process blocks or not by setting ``detach``. Note: when
 ``detach is True`` it is not possible to tee the output.
 
 Example:
@@ -20,7 +20,8 @@ Example:
     >>> # Running with verbose=1 will write to stdout in real time
     >>> info = ub.cmd('echo "write your command naturally"', verbose=1)
     write your command naturally
-    >>> # Unless `detach=True`, `cmd` always returns an info dict.
+    >>> # The return type is a dictionary of information depending
+    >>> # on how `ub.cmd` was invoked.
     >>> print('info = ' + ub.repr2(info))
     info = {
         'command': 'echo "write your command naturally"',
@@ -111,7 +112,7 @@ def cmd(command, shell=False, detach=False, verbose=0, tee=None, cwd=None,
             dependant way. Other arguments such as env, tee, timeout, and shell
             are all ignored.  (new in version 1.1.0)
 
-        timeout (float):
+        timeout (float | None):
             If the process does not complete in `timeout` seconds, raises a
             :class:`subprocess.TimeoutExpired`. (new in version 1.1.0)
             Currently unhandled when tee is True.
@@ -133,11 +134,6 @@ def cmd(command, shell=False, detach=False, verbose=0, tee=None, cwd=None,
         subprocess.CalledProcessError - if check and the return value is non zero
 
     Note:
-        Inputs can either be text or tuple based. On UNIX we ensure conversion
-        to text if shell=True, and to tuple if shell=False. On windows, the
-        input is always text based.  See [SO_33560364]_ for a potential
-        cross-platform shlex solution for windows.
-
         When using the tee output, the stdout and stderr may be shuffled from
         what they would be on the command line.
 
@@ -232,7 +228,7 @@ def cmd(command, shell=False, detach=False, verbose=0, tee=None, cwd=None,
     """
     # In the future we might allow the user to pass a custom log function
     # But this has weird interactions with how the tee process works
-    # becasue of the assumption stdout.write does not emit a newline
+    # because of the assumption stdout.write does not emit a newline
     log = print
 
     import subprocess
@@ -252,18 +248,26 @@ def cmd(command, shell=False, detach=False, verbose=0, tee=None, cwd=None,
         command_tup = tuple(command_parts)
         command_text = ' '.join(list(map(pipes.quote, command_tup)))
 
-    if shell or sys.platform.startswith('win32'):
+    # Inputs can either be text or tuple based. On UNIX we ensure conversion
+    # to text if shell is True, and to tuple if shell is False. On windows,
+    # the input is text if shell is True, but can be either if shell is
+    # False as noted in [SO_33560364]_.
+    if shell:
         # When shell=True, args is sent to the shell (e.g. bin/sh) as text
         args = command_text
     else:
         # When shell=False, args is a list of executable and arguments
         if command_tup is None:
-            # parse this out of the string
-            # NOTE: perhaps use the solution from [SO_33560364] here?
-            import shlex
-            command_tup = shlex.split(command_text)
-            # command_tup = shlex.split(command_text, posix=not WIN32)
-        args = command_tup
+            if sys.platform.startswith('win32'):  # nocover
+                # On windows when shell=False, args can be a str | List[str]
+                # as noted in [SO_33560364]
+                args = command_text
+            else:
+                # On linux when shell=False, args must be a List[str]
+                import shlex
+                args = shlex.split(command_text)
+        else:
+            args = command_tup
 
     if tee is None:
         tee = verbose > 0
@@ -301,7 +305,9 @@ def cmd(command, shell=False, detach=False, verbose=0, tee=None, cwd=None,
             'out': None,
             'err': None,
         }
-        ret = os.system(command_text)
+        from ubelt.util_path import ChDir
+        with ChDir(cwd):
+            ret = os.system(command_text)
         info['ret'] = ret
     elif detach:
         info = {'proc': make_proc(), 'command': command_text}
@@ -309,7 +315,7 @@ def cmd(command, shell=False, detach=False, verbose=0, tee=None, cwd=None,
             log('...detaching')
     else:
         if tee:
-            # We logging stdout and stderr, while simulaniously piping it to
+            # We logging stdout and stderr, while simultaneously piping it to
             # another stream.
             stdout = sys.stdout
             stderr = sys.stderr
@@ -326,7 +332,7 @@ def cmd(command, shell=False, detach=False, verbose=0, tee=None, cwd=None,
                 try:
                     (out, err) = proc.communicate(timeout=timeout)
                 except subprocess.TimeoutExpired as exc:
-                    # Follow the error handling in the stdlib implementaton of
+                    # Follow the error handling in the stdlib implementation of
                     # subprocess.run
                     proc.kill()
                     if WIN32:  # nocover
@@ -461,7 +467,7 @@ def _enqueue_output_thread_worker(proc, stream, out_queue, control_queue, timeou
         # Alternate between checking if we were stopped and putting the item in
         # the queue. This helps with the issue of an open process stream on
         # exit but it doesn't fully solve the issue because we still might
-        # block on the stream.readline, therefore we can't guarentee this
+        # block on the stream.readline, therefore we can't guarantee this
         # thread will exit before the process does.
         if timeout is None:
             # If timeout is None, we can optimize this and just use the
@@ -496,7 +502,7 @@ def _enqueue_output_thread_worker(proc, stream, out_queue, control_queue, timeou
     if _check_if_stopped():  # nocover
         return
 
-    # Coverage note: on Python 3.10 it seems like the tests dont always cover
+    # Coverage note: on Python 3.10 it seems like the tests don't always cover
     # these lines. We don't have much control over if this happens or not, so
     # we will exclude them from coverage checks.
     for line in _textio_iterlines(stream):  # nocover
@@ -554,7 +560,7 @@ def _proc_iteroutput_thread(proc, timeout=None):
             if elapsed >= timeout:
                 stdout_ctrl.put('STOP')
                 stderr_ctrl.put('STOP')
-                # Unfortunately we can't guarentee that the threads will stop
+                # Unfortunately we can't guarantee that the threads will stop
                 # because they might get stuck in a readline
                 # stdout_thread.join()
                 # stderr_thread.join()
