@@ -22,8 +22,8 @@ __all__ = ['download', 'grabdata']
 
 
 def download(url, fpath=None, dpath=None, fname=None, appname=None,
-             hash_prefix=None, hasher='sha512', chunksize=8192, verbose=1,
-             timeout=NoParam, progkw=None):
+             hash_prefix=None, hasher='sha512', chunksize=8192, filesize=None,
+             verbose=1, timeout=NoParam, progkw=None):
     """
     Downloads a url to a file on disk.
 
@@ -50,7 +50,7 @@ def download(url, fpath=None, dpath=None, fname=None, appname=None,
             What to name the downloaded file. Defaults to the url basename.
             Mutually exclusive with fpath.
 
-        appname (str): set dpath to
+        appname (str | None): set dpath to
             ``ub.get_app_cache_dir(appname or 'ubelt')`` if dpath and fpath are
             not given.
 
@@ -63,7 +63,11 @@ def download(url, fpath=None, dpath=None, fname=None, appname=None,
             algorithm to apply to the file. Defaults to sha512.
 
         chunksize (int):
-            Download chunksize. Default to ``2 ** 13``
+            Download chunksize in bytes. Default to ``2 ** 13``
+
+        filesize (int | None):
+            If known, the filesize in bytes. If unspecified, attempts to
+            read that data from content headers.
 
         verbose (int | bool):
             Verbosity flag. Quiet is 0, higher is more verbose. Defaults to 1.
@@ -74,7 +78,7 @@ def download(url, fpath=None, dpath=None, fname=None, appname=None,
             This only works for HTTP, HTTPS and FTP connections for blocking
             operations like the connection attempt.
 
-        progkw (Dict | NoParamType):
+        progkw (Dict | NoParamType | None):
             if specified provides extra arguments to the progress iterator.
             See :class:`ubelt.progiter.ProgIter` for available options.
 
@@ -173,16 +177,17 @@ def download(url, fpath=None, dpath=None, fname=None, appname=None,
     urldata = urlopen(url, timeout=timeout)
 
     meta = urldata.info()
-    try:
-        if hasattr(meta, 'getheaders'):  # nocover
-            file_size = int(meta.getheaders("Content-Length")[0])
-        else:
-            file_size = int(meta.get_all("Content-Length")[0])
-    except Exception:  # nocover
-        # sometimes the url does not contain content length metadata
-        # TODO: find a public URL that exemplifies this or figure out how to
-        # mock it locally.
-        file_size = None
+    if filesize is None:
+        try:
+            if hasattr(meta, 'getheaders'):  # nocover
+                filesize = int(meta.getheaders("Content-Length")[0])
+            else:
+                filesize = int(meta.get_all("Content-Length")[0])
+        except Exception:  # nocover
+            # sometimes the url does not contain content length metadata
+            # TODO: find a public URL that exemplifies this or figure out how to
+            # mock it locally.
+            filesize = None
 
     if hash_prefix:
         if isinstance(hasher, str):
@@ -209,14 +214,35 @@ def download(url, fpath=None, dpath=None, fname=None, appname=None,
         # TODO: this outputs a lot of information that can bog down a CI
         # Might need to update defaults of ProgIter to reduce clutter
         _progkw = {
-            'total': file_size,
-            'freq': chunksize,
-            'time_thresh': 1,
+            'total': filesize,
+            # 'chunksize': chunksize,
+            # 'freq': chunksize,
+            'freq': 1,
+            'time_thresh': 2,
+            'adjust': False,
+            'show_rate': False,
         }
+        # import time
+        # start_time = time.monotonic()
+
+        def _build_extra():
+            pbar._curr_measurement.time
+            bytes_down = pbar._iter_idx
+            total_seconds = pbar._total_seconds + 1E-9
+            num_kb_down   = int(bytes_down) / 1024
+            num_mb_down   = int(num_kb_down / 1024)
+            kb_per_second = int(num_kb_down / (total_seconds))
+            # fmt_msg = ' {:d} MB, {:d} KB/s'
+            fmt_msg = ' {:d} KB/s'
+            msg = fmt_msg.format(num_mb_down, kb_per_second)
+            return msg
+
         if progkw is not None:
             _progkw.update(progkw)
         _progkw['disable'] = not verbose
         pbar = Progress(**_progkw)
+
+        pbar.set_extra(_build_extra)
         with pbar:
             _pbar_update = pbar.update
 
@@ -300,7 +326,7 @@ def grabdata(url, fpath=None, dpath=None, fname=None, redo=False,
         verbose (int):
             Verbosity flag. Quiet is 0, higher is more verbose. Defaults to 1.
 
-        appname (str): set dpath to
+        appname (str | None): set dpath to
             ``ub.get_app_cache_dir(appname or 'ubelt')`` if dpath and fpath are
             not given.
 
@@ -315,7 +341,7 @@ def grabdata(url, fpath=None, dpath=None, fname=None, redo=False,
             NOTE: Only pass hasher as a string. Passing as an instance is
             deprecated and can cause unexpected results.
 
-        expires (str | int | datetime.datetime):
+        expires (str | int | datetime.datetime | None):
             when the cache should expire and redownload or the number of
             seconds to wait before the cache should expire.
 
