@@ -335,7 +335,62 @@ def ensuredir(dpath, mode=0o1777, verbose=0, recreate=False):
     return dpath
 
 
-class TempDir(object):
+class ChDir:
+    """
+    Context manager that changes the current working directory and then
+    returns you to where you were.
+
+    Args:
+        dpath (str | PathLike | None):
+            The new directory to work in.
+            If None, then the context manager is disabled.
+
+    Example:
+        >>> import ubelt as ub
+        >>> dpath = ub.Path.appdir('ubelt/tests/chdir').ensuredir()
+        >>> dir1 = (dpath / 'dir1').ensuredir()
+        >>> dir2 = (dpath / 'dir2').ensuredir()
+        >>> with ChDir(dpath):
+        >>>     assert ub.Path.cwd() == dpath
+        >>>     # changes to the given directory, and then returns back
+        >>>     with ChDir(dir1):
+        >>>         assert ub.Path.cwd() == dir1
+        >>>         with ChDir(dir2):
+        >>>             assert ub.Path.cwd() == dir2
+        >>>             # changes inside the context manager will be reset
+        >>>             os.chdir(dpath)
+        >>>         assert ub.Path.cwd() == dir1
+        >>>     assert ub.Path.cwd() == dpath
+        >>>     with ChDir(dir1):
+        >>>         assert ub.Path.cwd() == dir1
+        >>>         with ChDir(None):
+        >>>             assert ub.Path.cwd() == dir1
+        >>>             # When disabled, the cwd does *not* reset at context exit
+        >>>             os.chdir(dir2)
+        >>>         assert ub.Path.cwd() == dir2
+        >>>         os.chdir(dir1)
+        >>>         # Dont change dirs, but reset to your cwd at context end
+        >>>         with ChDir('.'):
+        >>>             os.chdir(dir2)
+        >>>         assert ub.Path.cwd() == dir1
+        >>>     assert ub.Path.cwd() == dpath
+    """
+    def __init__(self, dpath):
+        self.context_dpath = dpath
+        self.orig_dpath = None
+
+    def __enter__(self):
+        if self.context_dpath is not None:
+            self.orig_dpath = os.getcwd()
+            os.chdir(self.context_dpath)
+        return self
+
+    def __exit__(self, a, b, c):
+        if self.context_dpath is not None:
+            os.chdir(self.orig_dpath)
+
+
+class TempDir:
     """
     Context for creating and cleaning up temporary directories.
 
@@ -664,7 +719,8 @@ class Path(_PathBase):
                 which by default is the parent directory.
 
             tail (str | None):
-                If specified, appends this text to the extension.
+                If specified, appends this text the very end of the path -
+                after the extension.
 
             relative (str | PathLike | None):
                 Replaces ``relative`` with ``dpath`` in ``path``.
@@ -677,9 +733,6 @@ class Path(_PathBase):
                 last dot in the basename is the extension. If True, everything
                 after the first dot in the basename is the extension.
 
-            suffix (str):
-                DEPRECAETD
-
         SeeAlso:
             :py:meth:`pathlib.Path.with_stem`
             :py:meth:`pathlib.Path.with_name`
@@ -765,7 +818,7 @@ class Path(_PathBase):
             from ubelt.util_deprecate import schedule_deprecation
             schedule_deprecation(
                 'ubelt', 'suffix', 'arg',
-                deprecate='1.1.3', remove='2.0.0',
+                deprecate='1.1.3', remove='1.4.0',
                 migration='Use stemsuffix instead',
             )
             if not stemsuffix:
@@ -775,8 +828,9 @@ class Path(_PathBase):
                 'DEVELOPER NOTICE: The ubelt.Path.augment function may '
                 'experience a BACKWARDS INCOMPATIBLE update in the future '
                 'having to do with the suffix argument to ub.Path.augment '
-                'To avoid any issue use the ``ubelt.augment`` function '
-                'instead for now. If you see this warning, please make an '
+                'To avoid any issue use the ``stemsuffix` argument or use the '
+                '``ubelt.augpath`` function instead. '
+                'If you see this warning, please make an '
                 'issue on https://github.com/Erotemic/ubelt/issues indicating '
                 'that there are users of this function in the wild. If there '
                 'are none, then this signature will be "fixed", but if anyone '
@@ -895,16 +949,27 @@ class Path(_PathBase):
         """
         return self.__class__(os.path.expandvars(self))
 
-    def ls(self):
+    def ls(self, pattern=None):
         """
         A convenience function to list all paths in a directory.
 
         This is simply a wraper around iterdir that returns the results as a
         list instead of a generator. This is mainly for faster navigation in
-        IPython. In production code `iterdir` should be used instead.
+        IPython. In production code ``iterdir`` or ``glob`` should be used
+        instead.
+
+        Args:
+            pattern (None | str):
+                if specified, performs a glob instead of an iterdir.
 
         Returns:
-            List[Path]
+            List[Path]: an eagerly evaluated list of paths
+
+        Note:
+            When pattern is specified only paths matching the pattern are
+            returned, not the paths inside matched directories.  This is
+            different than bash semantics where the pattern is first expanded
+            and then ls is performed on all matching paths.
 
         Example:
             >>> import ubelt as ub
@@ -924,8 +989,18 @@ class Path(_PathBase):
                 Path('file1'),
                 Path('file2'),
             ]
+            >>> children = self.ls('dir*/*')
+            >>> assert isinstance(children, list)
+            >>> print(ub.repr2(sorted([p.relative_to(self) for p in children])))
+            [
+                Path('dir1/file3'),
+                Path('dir2/file4'),
+            ]
         """
-        return list(self.iterdir())
+        if pattern is None:
+            return list(self.iterdir())
+        else:
+            return list(self.glob(pattern))
 
     def shrinkuser(self, home='~'):
         """
@@ -981,7 +1056,7 @@ class Path(_PathBase):
                 if True starts yield nodes closer to the root first otherwise
                 yield nodes closer to the leaves first.
 
-            onerror (Callable[[OSError], None]):
+            onerror (Callable[[OSError], None] | None):
                 A function with one argument of type OSError. If the
                 error is raised the walk is aborted, otherwise it continues.
 
